@@ -32,7 +32,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 sub db {
   my $self = shift;
@@ -188,8 +188,8 @@ holding on to them only for short amounts of time.
 
 While all I/O operations are performed blocking, you can wait for long running
 queries asynchronously, allowing the L<Mojo::IOLoop> event loop to perform
-other tasks in the meantime. Since database connections usually have a very
-low latency, this often results in very good performance.
+other tasks in the meantime. Since database connections usually have a very low
+latency, this often results in very good performance.
 
 Every database connection can only handle one active query at a time, this
 includes asynchronous ones. So if you start more than one, they will be put on
@@ -275,8 +275,7 @@ Database password, defaults to an empty string.
   $pg        = $pg->pubsub(Mojo::Pg::PubSub->new);
 
 L<Mojo::Pg::PubSub> object you can use to send and receive notifications very
-efficiently, by sharing a single database connection with many consumers. Note
-that this attribute is EXPERIMENTAL and might change without warning!
+efficiently, by sharing a single database connection with many consumers.
 
   # Subscribe to a channel
   $pg->pubsub->listen(news => sub {
@@ -305,8 +304,8 @@ following new ones.
 
 Get L<Mojo::Pg::Database> object for a cached or newly established database
 connection. The L<DBD::Pg> database handle will be automatically cached again
-when that object is destroyed, so you can handle connection timeouts
-gracefully by holding on to it only for short amounts of time.
+when that object is destroyed, so you can handle connection timeouts gracefully
+by holding on to it only for short amounts of time.
 
   # Add up all the money
   say $pg->db->query('select * from accounts')
@@ -350,6 +349,26 @@ L</"from_string"> if necessary.
   # Customize configuration further
   my $pg = Mojo::Pg->new->dsn('dbi:Pg:service=foo');
 
+=head1 REFERENCE
+
+This is the class hierarchy of the L<Mojo::Pg> distribution.
+
+=over 2
+
+=item * L<Mojo::Pg>
+
+=item * L<Mojo::Pg::Database>
+
+=item * L<Mojo::Pg::Migrations>
+
+=item * L<Mojo::Pg::PubSub>
+
+=item * L<Mojo::Pg::Results>
+
+=item * L<Mojo::Pg::Transaction>
+
+=back
+
 =head1 AUTHOR
 
 Sebastian Riedel, C<sri@cpan.org>.
