@@ -57,13 +57,13 @@ sub migrate {
   my $sql;
   if ($active < $target) {
     my @up = grep { $_ <= $target && $_ > $active } sort keys %$up;
-    $sql = join '', map { $up->{$_} } @up;
+    $sql = join '', @$up{@up};
   }
 
   # Down
   else {
     my @down = grep { $_ > $target && $_ <= $active } reverse sort keys %$down;
-    $sql = join '', map { $down->{$_} } @down;
+    $sql = join '', @$down{@down};
   }
 
   warn "-- Migrate ($active -> $target)\n$sql\n" if DEBUG;
@@ -122,6 +122,7 @@ C<-- VERSION UP/DOWN>.
   insert into messages values ('I ♥ Mojolicious!');
   -- 1 down
   drop table messages;
+
   -- 2 up (...you can comment freely here...)
   create table stuff (whatever int);
   -- 2 down
@@ -209,8 +210,8 @@ Latest version available.
   $migrations = $migrations->migrate;
   $migrations = $migrations->migrate(3);
 
-Migrate from L</"active"> to a different version, up or down, defaults to
-using L</"latest">. All version numbers need to be positive, with version C<0>
+Migrate from L</"active"> to a different version, up or down, defaults to using
+L</"latest">. All version numbers need to be positive, with version C<0>
 representing an empty database.
 
   # Reset database
